<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\entities\componentEntity;

class Content extends componentEntity
{
    public function init(): void
    {
        $this->addClass('col-lg-9 col-md-8 col-xl-10');
    }
}
