<?php

namespace apexl\Io\modules\display\controllers;

use apexl\Io\includes\Controller;
use apexl\Io\modules\component\Factories\GenericComponentFactory;
use apexl\Io\modules\display\services\Render;
use apexl\Io\services\Output;
use apexl\Io\services\RecursionFinderService;

;

readonly class DisplayController extends Controller
{
    public function __construct(
        protected GenericComponentFactory $componentFactory,
        protected Render $render,
        RecursionFinderService $recursionFinderService,
        Output $output,
    ) {
        parent::__construct($output, $recursionFinderService);
    }
}
