<?php

namespace apexl\Io\modules\display\components\form;

class InputField extends BaseField
{
    public string $name = 'InputField';

    public function init(): void
    {
        $this->setInputType('text');
    }

    public function setInputType(string $type): InputField
    {
        return $this->addProperty('inputType', $type);
    }

    public function setPlaceholder(string $text): InputField
    {
        return $this->addProperty('placeholder', $text);

    }
}
